@@ -15,13 +15,13 @@
 
 // Caml name: is_printable
 // Type:      char -> bool
-RT.caml_is_printable = function (c) {
+function caml_is_printable (c) {
     return mk_bool (c >= 0x20);
 }
 
 // Caml name: unsafe_fill
 // Type:      string -> int -> int -> char -> unit
-RT.caml_fill_string = function (s, st, len, c) {
+function caml_fill_string (s, st, len, c) {
     for (var i = 0;i < len;i++)
 	s.set (st + i, c);
     return UNIT;
@@ -29,7 +29,7 @@ RT.caml_fill_string = function (s, st, len, c) {
 
 // Caml name: string_create
 // Type:      int -> string
-RT.caml_create_string = function (len) {
+function caml_create_string (len) {
     var b = mk_block (len + 1, STRING_TAG);
     for (var i = 0;i <= len;i++)
 	b.set (i, 0);
@@ -38,7 +38,7 @@ RT.caml_create_string = function (len) {
 
 // Caml name: string_blit
 // Type:      string -> int -> string -> int -> int -> unit
-RT.caml_blit_string = function (s1, ofs1, s2, ofs2, n) {
+function caml_blit_string (s1, ofs1, s2, ofs2, n) {
     for (var i = 0;i < n;i++) {
 	s2.set (ofs2 + i, s1.get (ofs1 + i));
     }
@@ -47,7 +47,7 @@ RT.caml_blit_string = function (s1, ofs1, s2, ofs2, n) {
 
 // Caml name: get
 // Type:      string -> int -> char
-RT.caml_string_get = function (arr, idx) {
+function caml_string_get (arr, idx) {
     if (idx >= 0 && idx < arr.size - 1) {
 	return arr.get(idx);
     }
@@ -56,13 +56,13 @@ RT.caml_string_get = function (arr, idx) {
 
 // Caml name: unsafe_get
 // Type:      string -> int -> char
-RT.caml_string_unsafe_get = function (arr, idx) {
+function caml_string_unsafe_get (arr, idx) {
     return arr.get(idx);
 }
 
 // Caml name: set
 // Type:      string -> int -> char -> unit
-RT.caml_string_set = function (arr, idx, val) {
+function caml_string_set (arr, idx, val) {
     if (idx >= 0 && idx < arr.size - 1) {
 	arr.set(idx,val);
 	return UNIT;
@@ -72,14 +72,14 @@ RT.caml_string_set = function (arr, idx, val) {
 
 // Caml name: unsafe_set
 // Type:      string -> int -> char -> unit
-RT.caml_string_unsafe_set = function (arr, idx, val) {
+function caml_string_unsafe_set (arr, idx, val) {
     arr.set(idx,val);
     return UNIT;
 }
 
 // Caml name: string_length
 // Type:      string -> int
-RT.caml_ml_string_length = function (s) {
+function caml_ml_string_length (s) {
     return (s.size - 1);
 }
 
@@ -91,9 +91,9 @@ RT.caml_ml_string_length = function (s) {
 
 // Caml name: get
 // Type:      'a array -> int -> 'a
-RT.caml_array_get = 
-RT.caml_array_get_addr = 
-RT.caml_array_get_float = function (arr, idx) {
+caml_array_get = 
+caml_array_get_addr = 
+caml_array_get_float = function (arr, idx) {
     if (idx >= 0 && idx < arr.size) {
 	return arr.get(idx);
     }
@@ -102,9 +102,9 @@ RT.caml_array_get_float = function (arr, idx) {
 
 // Caml name: set
 // Type:      'a array -> int -> 'a -> unit
-RT.caml_array_set = 
-RT.caml_array_set_addr = 
-RT.caml_array_set_float = function (arr, idx, val) {
+caml_array_set = 
+caml_array_set_addr = 
+caml_array_set_float = function (arr, idx, val) {
     if (idx >= 0 && idx < arr.size) {
 	arr.set(idx,val);
 	return UNIT;
@@ -114,24 +114,24 @@ RT.caml_array_set_float = function (arr, idx, val) {
 
 // Caml name: unsafe_get
 // Type:      'a array -> int -> 'a
-RT.caml_array_unsafe_get = 
-RT.caml_array_unsafe_get_addr = 
-RT.caml_array_unsafe_get_float = function (arr, idx) {
+caml_array_unsafe_get = 
+caml_array_unsafe_get_addr = 
+caml_array_unsafe_get_float = function (arr, idx) {
     return arr.get(idx);
 }
 
 // Caml name: unsafe_set
 // Type:      'a array -> int -> 'a -> unit
-RT.caml_array_unsafe_set = 
-RT.caml_array_unsafe_set_addr = 
-RT.caml_array_unsafe_set_float = function (arr, idx, val) {
+caml_array_unsafe_set = 
+caml_array_unsafe_set_addr = 
+caml_array_unsafe_set_float = function (arr, idx, val) {
     arr.set(idx,val);
     return UNIT;
 }
 
 // Caml name: make
 // Type:      int -> 'a -> 'a array
-RT.caml_make_vect = function (len, init) {
+caml_make_vect = function (len, init) {
     var b = mk_block (len, 0);
     for (var i = 0;i < len;i++) {
 	b.set(i,init);
@@ -141,7 +141,7 @@ RT.caml_make_vect = function (len, init) {
 
 // Caml name: make_array
 // Type:      'a array -> 'a array
-RT.caml_make_array = function (init) {
+caml_make_array = function (init) {
     var b = mk_block (init.size, 0);
     for (var i = 0;i < init.size;i++) {
 	b.set(i,init.get (i));
@@ -155,7 +155,10 @@ RT.caml_make_array = function (init) {
 //                                                                           //
 ///////////////////////////////////////////////////////////////////////////////
 
-function caml_compare (a,b) {
+// Caml name: compare
+// Type:      'a -> 'a -> int
+caml_string_compare =
+caml_compare = function (a,b) {
     if (a == b)	return 0;
     if (!is_block(a)) {
 	if (is_block(b)) {
@@ -192,69 +195,61 @@ function caml_compare (a,b) {
     return 0;
 }
 
-
-// Caml name: compare
-// Type:      'a -> 'a -> int
-RT.caml_string_compare =
-RT.caml_compare = function (a, b) {
-    return caml_compare (a,b);
-}
-
 // Caml name: (=)
 // Type:      'a -> 'a -> bool
-RT.caml_equal = function (a, b) {
+function caml_equal (a, b) {
     return mk_bool (caml_compare (a,b) == 0);
 }
 
 // Caml name: (<>)
 // Type:      'a -> 'a -> bool
-RT.caml_notequal = function (a, b) {
+function caml_notequal (a, b) {
     return mk_bool (caml_compare (a,b) != 0);
 }
 
 // Caml name: (=)
 // Type:      'a -> 'a -> bool
-RT.caml_string_equal = function (a, b) {
+function caml_string_equal (a, b) {
     return mk_bool (caml_compare (a,b) == 0);
 }
 
 // Caml name: (<>)
 // Type:      'a -> 'a -> bool
-RT.caml_string_notequal = function (a, b) {
+function caml_string_notequal (a, b) {
     return mk_bool (caml_compare (a,b) != 0);
 }
 
 // Caml name: (<)
 // Type:      'a -> 'a -> bool
-RT.caml_lessthan =
-RT.caml_lt_float = function (a, b) {
+caml_lessthan =
+caml_lt_float = function (a, b) {
     return mk_bool (caml_compare (a,b) < 0);
 }
 
 // Caml name: (<=)
 // Type:      'a -> 'a -> bool
-RT.caml_lessequal =
-RT.caml_le_float = function (a, b) {
+caml_lessequal =
+caml_le_float = function (a, b) {
     return mk_bool (caml_compare (a,b) <= 0);
 }
 
 // Caml name: (>)
 // Type:      'a -> 'a -> bool
-RT.caml_greaterthan =
-RT.caml_gt_float = function (a, b) {
+caml_greaterthan =
+caml_gt_float = function (a, b) {
     return mk_bool (caml_compare (a,b) > 0);
 }
 
 // Caml name: (>=)
 // Type:      'a -> 'a -> bool
-RT.caml_greaterequal =
-RT.caml_ge_float = function (a, b) {
+caml_greaterequal =
+caml_ge_float = function (a, b) {
     return mk_bool (caml_compare (a,b) >= 0);
 }
 
 // Caml name: (=)
 // Type:      'a -> 'a -> bool
-RT.caml_eq_float = function (a, b) {
+caml_eq_float = function (a, b) {
     return mk_bool (caml_compare (a,b) == 0);
 }
 
@@ -264,6 +259,8 @@ RT.caml_eq_float = function (a, b) {
 //                                                                           //
 ///////////////////////////////////////////////////////////////////////////////
 
+// Caml name: hash_param
+// Type:      int -> int -> 'a -> int
 function caml_hash_univ_param (count, limit, obj) {
     hash_univ_limit = limit;
     hash_univ_count = count;
@@ -283,7 +280,7 @@ function hash_aux(obj){
     
     if (is_long(obj)) {
 	hash_univ_count--;
-	COMBINE(Long_val(obj));
+	COMBINE(obj);
 	return;
     }
     
@@ -296,7 +293,7 @@ function hash_aux(obj){
     }
     case DOUBLE_TAG: {
 	hash_univ_count--;
-	var bytes = bytes_of_float (unbox_float (obj));
+	var bytes = bytes_of_float (obj);
 	for (var p = 7; p >= 0; p--)
             COMBINE_SMALL(bytes[p]);
 	break;
@@ -344,12 +341,6 @@ function hash_aux(obj){
     return;
 }
 
-// Caml name: hash_param
-// Type:      int -> int -> 'a -> int
-RT.caml_hash_univ_param = function (count, limit, obj) {
-    return caml_hash_univ_param (count, limit, obj);
-}
-
 ///////////////////////////////////////////////////////////////////////////////
 //                                                                           //
 //  CASTS                                                                    //
@@ -357,7 +348,7 @@ RT.caml_hash_univ_param = function (count, limit, obj) {
 ///////////////////////////////////////////////////////////////////////////////
 // Caml name: format_int
 // Type:      string -> int -> string
-RT.caml_format_int = function (fmt, x) {
+function caml_format_int (fmt, x) {
     var fmt = string_from_value (fmt);
     var t = fmt[fmt.length - 1];
     var n = Number (x).toString (t == 'd' ? 10 : (t == 'o' ? 8 : (t == 'x' ? 16 : 10 /* err */)));
@@ -379,14 +370,14 @@ RT.caml_format_int = function (fmt, x) {
 
 // Caml name: format_float
 // Type:      string -> float -> string
-RT.caml_format_float = function (fmt, x) {
+function caml_format_float (fmt, x) {
     /* format unused */
     return value_from_string (unbox_float (x).toString (10));
 }
 
 // Caml name: int_of_string
 // Type:      string -> int
-RT.caml_int_of_string = function (s) {
+function caml_int_of_string (s) {
     var res = parseInt (string_from_value (s));
     if (isNaN (res)) {
 	this.failwith ("int_of_string");
@@ -397,25 +388,25 @@ RT.caml_int_of_string = function (s) {
 
 // Caml name: float_of_string
 // Type:      string -> int
-RT.caml_float_of_string = function (s) {
+function caml_float_of_string (s) {
     return box_float (parseFloat (string_from_value (s)));
 }
 
 // Caml name: int_of_float
 // Type:      float -> int
-RT.caml_int_of_float = function (x) {
+function caml_int_of_float (x) {
     return int_of_float (x);
 }
 
 // Caml name: float_of_int, float
 // Type:      int -> float
-RT.caml_float_of_int = function (x) {
+function caml_float_of_int (x) {
     return float_of_int (x);
 }
 
 // Caml name: float_of_bits
 // Type:      int64 -> float
-RT.caml_int64_float_of_bits = function (i) {
+function caml_int64_float_of_bits (i) {
     return float_of_bytes (int64_to_bytes (i));
 }
 
@@ -427,150 +418,150 @@ RT.caml_int64_float_of_bits = function (i) {
 
 // Caml name: ( *. )
 // Type:      float -> float -> float
-RT.caml_mul_float = function (a, b) {
+function caml_mul_float (a, b) {
     return box_float (unbox_float (a) * unbox_float (b));
 }
 
 // Caml name: ( /. )
 // Type:      float -> float -> float
-RT.caml_div_float = function (a, b) {
+function caml_div_float (a, b) {
     return box_float (unbox_float (a) / unbox_float (b));
 }
 
 // Caml name: (~-.)
 // Type:      float -> float
-RT.caml_neg_float = function (a) {
+function caml_neg_float (a) {
     return box_float (- unbox_float (b));
 }
 // Caml name: (+.)
 // Type:      float -> float -> float
-RT.caml_add_float = function (a, b) {
+function caml_add_float (a, b) {
     return box_float (unbox_float (a) + unbox_float (b));
 }
 // Caml name: (-.)
 // Type:      float -> float -> float
-RT.caml_sub_float = function (a, b) {
+function caml_sub_float (a, b) {
     return box_float (unbox_float (a) - unbox_float (b));
 }
 
 // Caml name: ( ** )
 // Type:      float -> float -> float
-RT.caml_power_float =
-RT.pow = function (a, b) {
+caml_power_float =
+pow = function (a, b) {
     return box_float (Math.pow (unbox_float (a), unbox_float (b)));
 }
 
 // Caml name: exp
 // Type:      float -> float
-RT.caml_exp_float =
-RT.exp = function (a, b) {
+caml_exp_float =
+exp = function (a, b) {
     return box_float (Math.exp (unbox_float (a), unbox_float (b)));
 }
 
 // Caml name: acos
 // Type:      float -> float
-RT.caml_acos_float =
-RT.acos = function (x) {
+caml_acos_float =
+acos = function (x) {
     return box_float (Math.acos (unbox_float (x)));
 }
 
 // Caml name: asin
 // Type:      float -> float
-RT.caml_asin_float =
-RT.asin = function (x) {
+caml_asin_float =
+asin = function (x) {
     return box_float (Math.asin (unbox_float (x)));
 }
 
 // Caml name: atan
 // Type:      float -> float
-RT.caml_atan_float =
-RT.atan = function (x) {
+caml_atan_float =
+atan = function (x) {
     return box_float (Math.atan (unbox_float (x)));
 }
 
 // Caml name: atan2
 // Type:      float -> float -> float
-RT.caml_atan2_float =
-RT.atan2 = function (a, b) {
+caml_atan2_float =
+atan2 = function (a, b) {
     return box_float (Math.atan2 (unbox_float (a), unbox_float (b)));
 }
 
 // Caml name: cos
 // Type:      float -> float
-RT.caml_cos_float =
-RT.cos = function (x) {
+caml_cos_float =
+cos = function (x) {
     return box_float (Math.cos (unbox_float (x)));
 }
 
 // Caml name: cosh
 // Type:      float -> float
-RT.caml_cosh_float =
-RT.cosh = function (x) {
+caml_cosh_float =
+cosh = function (x) {
     x = unbox_float (x);
     return box_float ((Math.exp (x) + Math.exp (-x)) / 2);
 }
 
 // Caml name: log
 // Type:      float -> float
-RT.caml_log_float =
-RT.log = function (x) {
+caml_log_float =
+log = function (x) {
     return box_float (Math.log (unbox_float (x)));
 }
 
 // Caml name: log10
 // Type:      float -> float
-RT.caml_log10_float =
-RT.log10 = function () {
+caml_log10_float =
+log10 = function () {
     return box_float (Math.log (unbox_float (x)) / Math.log (10));
 }
 
 // Caml name: sin
 // Type:      float -> float
-RT.caml_sin_float =
-RT.sin = function (x) {
+caml_sin_float =
+sin = function (x) {
     return box_float (Math.sin (unbox_float (x)));
 }
 
 // Caml name: sinh
 // Type:      float -> float
-RT.caml_sinh_float =
-RT.sinh = function (x) {
+caml_sinh_float =
+sinh = function (x) {
     x = unbox_float (x);
     return box_float ((Math.exp (x) - Math.exp (-x)) / 2);
 }
 
 // Caml name: sqrt
 // Type:      float -> float
-RT.caml_sqrt_float =
-RT.sqrt = function (x) {
+caml_sqrt_float =
+sqrt = function (x) {
     return box_float (Math.sqrt (unbox_float (x)));
 }
 
 // Caml name: tan
 // Type:      float -> float
-RT.caml_tan_float =
-RT.tan = function (x) {
+caml_tan_float =
+tan = function (x) {
     return box_float (Math.tan (unbox_float (x)));
 }
 
 // Caml name: tanh
 // Type:      float -> float
-RT.caml_tanh_float =
-RT.tanh = function (x) {
+caml_tanh_float =
+tanh = function (x) {
     return box_float (Math.tanh (unbox_float (x)));
 }
 
 // Caml name: ceil
 // Type:      float -> float
-RT.caml_ceil_float =
-RT.ceil = function (x) {
+caml_ceil_float =
+ceil = function (x) {
     return box_float (Math.ceil (unbox_float (x)));
 }
 
 // Caml name: floor
 // Type:      float -> float
-RT.caml_floor_float =
-RT.floor = function (x) {
+caml_floor_float =
+floor = function (x) {
     return box_float (Math.floor (unbox_float (x)));
 }
 
@@ -585,63 +576,63 @@ var named_values = [];
 
 // Caml name: register_named_value
 // Type:      string -> 'a -> unit
-RT.caml_register_named_value = function (vname, val) {
+function caml_register_named_value (vname, val) {
     named_values[string_from_value (vname)] = val;
     return UNIT;
 }
 
 // Type:      int -> unit
-RT.caml_ensure_stack_capacity = function (required_space) {
+function caml_ensure_stack_capacity (required_space) {
     return UNIT;
 }
 
 // Caml name: is_block
 // Type:      t -> bool
-RT.caml_obj_is_block = function (x) {
+function caml_obj_is_block (x) {
     return mk_bool (is_block (x));
 }
 // Caml name: is_int
 // Type:      t -> bool
-RT.caml_obj_is_int = function (x) {
+function caml_obj_is_int (x) {
     return mk_bool (is_long (x));
 }
 // Caml name: tag
 // Type:      t -> int
-RT.caml_obj_tag = function (x) {
+function caml_obj_tag (x) {
     return x.tag;
 }
 // Caml name: set_tag
 // Type:      t -> int -> unit
-RT.caml_obj_set_tag = function (x, tag) {
+function caml_obj_set_tag (x, tag) {
     x.tag = tag;
     return UNIT;
 }
 // Caml name: size
 // Type:      t -> int
-RT.caml_obj_size = function (x) {
+function caml_obj_size (x) {
     return x.size;
 }
 // Caml name: field
 // Type:      t -> int -> t
-RT.caml_obj_field = function (x, i) {
+function caml_obj_field (x, i) {
     return x.get (i);
 }
 // Caml name: set_field
 // Type:      t -> int -> t -> unit
-RT.caml_obj_set_field = function (x, i, v) {
+function caml_obj_set_field (x, i, v) {
     x.set (i, v);
     return UNIT;
 }
 // Caml name: new_block
 // Type:      int -> int -> t
-RT.caml_obj_block = function (tag, size) {
+function caml_obj_block (tag, size) {
     var b = mk_block (size, tag);
     return b;
 }
 
 // Caml name: dup
 // Type:      t -> t
-RT.caml_obj_dup = function (v) {
+function caml_obj_dup (v) {
     if (is_long (v))
 	return v;
     var b = mk_block (v.size, v.tag);
@@ -652,30 +643,31 @@ RT.caml_obj_dup = function (v) {
 
 // Caml name: truncate
 // Type:      t -> int -> unit
-RT.caml_obj_truncate = function (x, size) {
+function caml_obj_truncate (x, size) {
     x.size = size;
     return UNIT;
 }
 
 // Caml name: ldexp
 // Type:      float -> int -> float
-RT.caml_ldexp_float = function (m, e) {
+function caml_ldexp_float (m, e) {
     return box_float (m * Math.pow (2, unbox_float (e)));
 }
 
 // Caml name: frexp
 // Type:      float -> float * int
-RT.caml_frexp_float = function (v) {
+function caml_frexp_float (v) {
     var x = unbox_float (v);
     var e = Math.ceil (Math.log (Math.abs (x)) / Math.log (2));
     return pair (box_float (x * Math.pow (2, -e)), e);
 }
 
-RT.caml_alloc_dummy = function (size) {
+caml_alloc_dummy =
+caml_alloc_dummy_float = function (size) {
     return mk_block (size, 0);
 }
 
-RT.caml_update_dummy = function (dummy, newval) {
+function caml_update_dummy (dummy, newval) {
 //    if (!is_block(dummy) || !is_block(newval) || dummy.size != newval.size) {
 //	this.failwith ("caml_update_dummy");
 //    }
@@ -688,32 +680,32 @@ RT.caml_update_dummy = function (dummy, newval) {
 /*
 // Caml name: abs_float
 // Type:      float -> float
-RT.%absfloat = function () {
+%absfloat = function () {
   throw new Error ("%absfloat" + " not implemented");
 }
 
 // Caml name: mod_float
 // Type:      float -> float -> float
-RT.caml_fmod_float =
-RT.fmod = function () {
+caml_fmod_float =
+fmod = function () {
   throw new Error ("caml_fmod_float" + " not implemented");
 }
 
 // Caml name: modf
 // Type:      float -> float * float
-RT.caml_modf_float = function () {
+caml_modf_float = function () {
   throw new Error ("caml_modf_float" + " not implemented");
 }
 
 // Caml name: classify_float
 // Type:      float -> fpclass
-RT.caml_classify_float = function () {
+caml_classify_float = function () {
   throw new Error ("caml_classify_float" + " not implemented");
 }
 
 // Caml name: sys_exit
 // Type:      int -> 'a
-RT.caml_sys_exit = function () {
+caml_sys_exit = function () {
   throw new Error ("caml_sys_exit" + " not implemented");
 }
 
